==> tlseparation-1.2.1.6-py2-none-any.whl: tlseparation/classification/classes_reference.py <==
# Copyright (c) 2017, Matheus Boni Vicari, TLSeparation Project
# All rights reserved.
#
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.


__author__ = "Matheus Boni Vicari"
__copyright__ = "Copyright 2017, TLSeparation Project"
__credits__ = ["Matheus Boni Vicari", "Phil Wilkes"]
__license__ = "GPL3"
__version__ = "1.2.1.5"
__maintainer__ = "Matheus Boni Vicari"
__email__ = "matheus.boni.vicari@gmail.com"
__status__ = "Development"


import numpy as np
from pandas import DataFrame


class DefaultClass:

    """
    Defines a defaul reference class to be used in classification of
    tree point clouds.

    """

    def __init__(self):
        self.ref_table = DataFrame(np.array([['leaf', 1, 0, 0, 0, 0, 0],
                                             ['twig', 0, 1, 0, 0, 0.5, 1],
                                             ['trunk', 0, 0, 1, 1, 0.5, 1]]),
                                   columns=['class', 0, 1, 2, 3, 4, 5])

==> tlseparation-1.2.1.7-py2-none-any.whl: tlseparation/classification/classes_reference.py <==
# Copyright (c) 2017, Matheus Boni Vicari, TLSeparation Project
# All rights reserved.
#
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.


__author__ = "Matheus Boni Vicari"
__copyright__ = "Copyright 2017, TLSeparation Project"
__credits__ = ["Matheus Boni Vicari", "Phil Wilkes"]
__license__ = "GPL3"
__version__ = "1.2.1.7"
__maintainer__ = "Matheus Boni Vicari"
__email__ = "matheus.boni.vicari@gmail.com"
__status__ = "Development"


import numpy as np
from pandas import DataFrame


class DefaultClass:

    """
    Defines a default reference class to be used in classification of
    tree point clouds.

    """

    def __init__(self):
        self.ref_table = DataFrame(np.array([['leaf', 1, 0, 0, 0, 0, 0],
                                             ['twig', 0, 1, 0, 0, 0.5, 1],
                                             ['trunk', 0, 0, 1, 1, 0.5, 1]]),
                                   columns=['class', 0, 1, 2, 3, 4, 5])
